allele.sharing(pop1, pop2, allele.column, onlypairs = FALSE,
value = NA, ref.pop)pop2 and row names from samples of pop1. Similarity indices can be calculated for each pair. Indices are calculated using allelic information of one locus which first column must be indicated by allele.column. allele.column+1 will be used automatically as second allele information.inputformat
Demerelate
emp.calc
queller## internal function not intended for direct useRun the code above in your browser using DataLab