relate.calc(tab.pop, pairs, file.output, value,
directory.name, ref.pop)Object - matrix of mean pairwise relatedness of all loci of each comparison in tab.pop.Object - matrix of mean pairwise relatedness of each randomized comparison of full siblings.file - matrix of mean pairwise relatedness of each randomized comparison of full siblings.Object - matrix of mean pairwise relatedness of each randomized comparison of half siblings.file - matrix of mean pairwise relatedness of each randomized comparison of half siblings.Object - matrix of mean pairwise relatedness of each randomized comparison of non relatives.file - matrix of mean pairwise relatedness of each randomized comparison of non relatives.Object - calculated thresholds for relatedness from reference populations.emp.calc
offspring
random.pairs
glm.prep## internal function not intended for usage without DemerelateRun the code above in your browser using DataLab